diff --git a/substrate/client/consensus/aura/src/lib.rs b/substrate/client/consensus/aura/src/lib.rs
index c538200bb3..a0eed6e353 100644
--- a/substrate/client/consensus/aura/src/lib.rs
+++ b/substrate/client/consensus/aura/src/lib.rs
@@ -257,7 +257,7 @@ pub fn build_aura_worker
(
SyncOracle = SO,
JustificationSyncLink = L,
Claim = P::Public,
- EpochData = Vec>,
+ AuxData = Vec>,
>
where
B: BlockT,
@@ -330,7 +330,7 @@ where
Pin> + Send + 'static>>;
type Proposer = E::Proposer;
type Claim = P::Public;
- type EpochData = Vec>;
+ type AuxData = Vec>;
fn logging_target(&self) -> &'static str {
"aura"
@@ -340,15 +340,15 @@ where
&mut self.block_import
}
- fn epoch_data(
+ fn aux_data(
&self,
header: &B::Header,
_slot: Slot,
- ) -> Result {
+ ) -> Result {
authorities(self.client.as_ref(), &BlockId::Hash(header.hash()))
}
- fn authorities_len(&self, epoch_data: &Self::EpochData) -> Option {
+ fn authorities_len(&self, epoch_data: &Self::AuxData) -> Option {
Some(epoch_data.len())
}
@@ -356,7 +356,7 @@ where
&self,
_header: &B::Header,
slot: Slot,
- epoch_data: &Self::EpochData,
+ epoch_data: &Self::AuxData,
) -> Option {
let expected_author = slot_author::(slot, epoch_data);
expected_author.and_then(|p| {
@@ -382,7 +382,7 @@ where
body: Vec,
storage_changes: StorageChanges<>::Transaction, B>,
public: Self::Claim,
- _epoch: Self::EpochData,
+ _epoch: Self::AuxData,
) -> Result<
sc_consensus::BlockImportParams>::Transaction>,
sp_consensus::Error,
diff --git a/substrate/client/consensus/babe/src/lib.rs b/substrate/client/consensus/babe/src/lib.rs
index aef4785b7b..109e5aade0 100644
--- a/substrate/client/consensus/babe/src/lib.rs
+++ b/substrate/client/consensus/babe/src/lib.rs
@@ -729,7 +729,6 @@ where
BS: BackoffAuthoringBlocksStrategy> + Sync,
Error: std::error::Error + Send + From + From + 'static,
{
- type EpochData = ViableEpochDescriptor, Epoch>;
type Claim = (PreDigest, AuthorityId);
type SyncOracle = SO;
type JustificationSyncLink = L;
@@ -737,6 +736,7 @@ where
Pin> + Send + 'static>>;
type Proposer = E::Proposer;
type BlockImport = I;
+ type AuxData = ViableEpochDescriptor, Epoch>;
fn logging_target(&self) -> &'static str {
"babe"
@@ -746,11 +746,7 @@ where
&mut self.block_import
}
- fn epoch_data(
- &self,
- parent: &B::Header,
- slot: Slot,
- ) -> Result {
+ fn aux_data(&self, parent: &B::Header, slot: Slot) -> Result {
self.epoch_changes
.shared_data()
.epoch_descriptor_for_child_of(
@@ -763,7 +759,7 @@ where
.ok_or(sp_consensus::Error::InvalidAuthoritiesSet)
}
- fn authorities_len(&self, epoch_descriptor: &Self::EpochData) -> Option {
+ fn authorities_len(&self, epoch_descriptor: &Self::AuxData) -> Option {
self.epoch_changes
.shared_data()
.viable_epoch(epoch_descriptor, |slot| Epoch::genesis(&self.config, slot))
@@ -823,7 +819,7 @@ where
body: Vec,
storage_changes: StorageChanges<>::Transaction, B>,
(_, public): Self::Claim,
- epoch_descriptor: Self::EpochData,
+ epoch_descriptor: Self::AuxData,
) -> Result<
sc_consensus::BlockImportParams>::Transaction>,
sp_consensus::Error,
diff --git a/substrate/client/consensus/slots/src/lib.rs b/substrate/client/consensus/slots/src/lib.rs
index 7c5d5d4a73..6225bbbda1 100644
--- a/substrate/client/consensus/slots/src/lib.rs
+++ b/substrate/client/consensus/slots/src/lib.rs
@@ -101,8 +101,8 @@ pub trait SimpleSlotWorker {
/// Data associated with a slot claim.
type Claim: Send + Sync + 'static;
- /// Epoch data necessary for authoring.
- type EpochData: Send + Sync + 'static;
+ /// Auxiliary data necessary for authoring.
+ type AuxData: Send + Sync + 'static;
/// The logging target to use when logging messages.
fn logging_target(&self) -> &'static str;
@@ -110,29 +110,28 @@ pub trait SimpleSlotWorker {
/// A handle to a `BlockImport`.
fn block_import(&mut self) -> &mut Self::BlockImport;
- /// Returns the epoch data necessary for authoring. For time-dependent epochs,
- /// use the provided slot number as a canonical source of time.
- fn epoch_data(
+ /// Returns the auxiliary data necessary for authoring.
+ fn aux_data(
&self,
header: &B::Header,
slot: Slot,
- ) -> Result;
+ ) -> Result;
- /// Returns the number of authorities given the epoch data.
+ /// Returns the number of authorities.
/// None indicate that the authorities information is incomplete.
- fn authorities_len(&self, epoch_data: &Self::EpochData) -> Option;
+ fn authorities_len(&self, aux_data: &Self::AuxData) -> Option;
/// Tries to claim the given slot, returning an object with claim data if successful.
async fn claim_slot(
&self,
header: &B::Header,
slot: Slot,
- epoch_data: &Self::EpochData,
+ aux_data: &Self::AuxData,
) -> Option;
/// Notifies the given slot. Similar to `claim_slot`, but will be called no matter whether we
/// need to author blocks or not.
- fn notify_slot(&self, _header: &B::Header, _slot: Slot, _epoch_data: &Self::EpochData) {}
+ fn notify_slot(&self, _header: &B::Header, _slot: Slot, _aux_data: &Self::AuxData) {}
/// Return the pre digest data to include in a block authored with the given claim.
fn pre_digest_data(&self, slot: Slot, claim: &Self::Claim) -> Vec;
@@ -145,7 +144,7 @@ pub trait SimpleSlotWorker {
body: Vec,
storage_changes: StorageChanges<>::Transaction, B>,
public: Self::Claim,
- epoch: Self::EpochData,
+ epoch: Self::AuxData,
) -> Result<
sc_consensus::BlockImportParams>::Transaction>,
sp_consensus::Error,
@@ -268,12 +267,12 @@ pub trait SimpleSlotWorker {
Delay::new(proposing_remaining_duration)
};
- let epoch_data = match self.epoch_data(&slot_info.chain_head, slot) {
- Ok(epoch_data) => epoch_data,
+ let aux_data = match self.aux_data(&slot_info.chain_head, slot) {
+ Ok(aux_data) => aux_data,
Err(err) => {
warn!(
target: logging_target,
- "Unable to fetch epoch data at block {:?}: {}",
+ "Unable to fetch auxiliary data for block {:?}: {}",
slot_info.chain_head.hash(),
err,
);
@@ -290,9 +289,9 @@ pub trait SimpleSlotWorker {
},
};
- self.notify_slot(&slot_info.chain_head, slot, &epoch_data);
+ self.notify_slot(&slot_info.chain_head, slot, &aux_data);
- let authorities_len = self.authorities_len(&epoch_data);
+ let authorities_len = self.authorities_len(&aux_data);
if !self.force_authoring() &&
self.sync_oracle().is_offline() &&
@@ -309,7 +308,7 @@ pub trait SimpleSlotWorker {
return None
}
- let claim = self.claim_slot(&slot_info.chain_head, slot, &epoch_data).await?;
+ let claim = self.claim_slot(&slot_info.chain_head, slot, &aux_data).await?;
if self.should_backoff(slot, &slot_info.chain_head) {
return None
@@ -351,7 +350,7 @@ pub trait SimpleSlotWorker {
body.clone(),
proposal.storage_changes,
claim,
- epoch_data,
+ aux_data,
)
.await
{